pub struct WordNet { /* private fields */ }Implementations
Sourceimpl WordNet
impl WordNet
pub fn new(dir: &Path) -> Result<Self>
pub fn contains(&self, word: &str) -> bool
Sourcepub fn resolve(
&self,
part_of_speech: PartOfSpeech,
offset: u64,
) -> Option<SynSet>
pub fn resolve( &self, part_of_speech: PartOfSpeech, offset: u64, ) -> Option<SynSet>
Directly resolve a reference, this should only be used with part_of_speech, offset pairs from the returned results, such as the relationships in synsets.
pub fn all_words(&self) -> Vec<String>
pub fn lemmatize(&self, word: &str) -> PartsOfSpeech<Vec<String>>
pub fn lemmatize_for(&self, word: &str, pos: PartOfSpeech) -> Vec<String>
pub fn synsets(&self, word: &str) -> PartsOfSpeech<Vec<SynSet>>
pub fn synsets_for(&self, word: &str, pos: PartOfSpeech) -> Vec<SynSet>